[coreboot-gerrit] New patch to review for coreboot: 0b4bfeb lenovo/t520/hda_verb.h: update azalia codec config

Nicolas Reinecke (nr@das-labor.org) gerrit at coreboot.org
Sat Sep 6 18:06:47 CEST 2014


Nicolas Reinecke (nr at das-labor.org) just uploaded a new patch set to gerrit, which you can find at http://review.coreboot.org/6849

-gerrit

commit 0b4bfeb9c39d2b57bfec396ef0c085d51cbde58e
Author: Nicolas Reinecke <nr at das-labor.org>
Date:   Sat Sep 6 18:03:05 2014 +0200

    lenovo/t520/hda_verb.h: update azalia codec config
    
    Replace codec config copied form T530 with dumped values from T520.
    Intel Azalia HDMI is always enabled, but DP isn't connected to a
    connector.
    
    Change-Id: Iabdae4a6669ff429d5769a1bb0c0fb1abc12ba82
    Signed-off-by: Nicolas Reinecke <nr at das-labor.org>
---
 src/mainboard/lenovo/t520/hda_verb.h | 100 +++++++----------------------------
 1 file changed, 19 insertions(+), 81 deletions(-)

diff --git a/src/mainboard/lenovo/t520/hda_verb.h b/src/mainboard/lenovo/t520/hda_verb.h
index 4248a7d..19eac1b 100644
--- a/src/mainboard/lenovo/t520/hda_verb.h
+++ b/src/mainboard/lenovo/t520/hda_verb.h
@@ -18,18 +18,18 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 /*	Vendor Name    : IDT
  *	Vendor ID      : 0x10ec0269
  *	Subsystem ID   : 0x17aa21fa
  *	Revision ID    : 0x100303
  */
 
 
 static const u32 mainboard_cim_verb_data[] = {
 	/* coreboot specific header */
-	0x10ec0269,	// Codec Vendor / Device ID: Realtek ALC269VC
-	0x17aa21fa,	// Subsystem ID
-	0x0000007d,	// Number of 4 dword sets
+	0x14f1506e,	// Codec Vendor / Device ID: Conexant CX20590 - Schematic shows CX20672
+	0x17aa21cf,	// Subsystem ID
+	0x00000077,	// Number of 4 dword sets
 
 /* Bits 31:28 - Codec Address */
 /* Bits 27:20 - NID */
@@ -37,56 +37,18 @@ static const u32 mainboard_cim_verb_data[] = {
 /* Bits 7:0  - Payload */
 
 /* NID 0x01 - NodeInfo */
-	AZALIA_SUBVENDOR(0x0, 0x17AA21FA),
-
-/* NID 0x0A - External Microphone Connector
- * Config=0x04A11020 (External,Right; MicIn,3.5mm; Black,JD; DA,Seq)
- */
-	AZALIA_PIN_CFG(0x0, 0x0A, 0x04A11020),
-
-/* NID 0x0B - Headphone Connector
- * Config=0x0421101F (External,Right; HP,3.5mm; Black,JD; DA,Seq)
- */
-	AZALIA_PIN_CFG(0x0, 0x0B, 0x0421101F),
-
-/* NID 0x0C - Not connected
- * Config=0x40F000F0 (N/A,N/A; Other,Unknown; Unknown,JD; DA,Seq)
- */
-	AZALIA_PIN_CFG(0x0, 0x0C, 0x40F000F0),
-
-/* NID 0x0D - Internal Speakers
- * Config=0x90170110 (Fixed,Int; Speaker,Other Analog; Unknown,nJD; DA,Seq)
- */
-	AZALIA_PIN_CFG(0x0, 0x0D, 0x90170110),
-
-/* NID 0x0F - Not connected
- * Config=0x40F000F0
- */
-	AZALIA_PIN_CFG(0x0, 0x0F, 0x40F000F0),
-
-/* NID 0x11 - Internal Microphone
- * Config=0xD5A30140 (Fixed internal,Top; Mic In,ATIPI; Unknown,nJD; DA,Seq)
- */
-	AZALIA_PIN_CFG(0x0, 0x11, 0xD5A30140),
-	AZALIA_PIN_CFG(0x0, 0x12, 0x90A60140),
-	AZALIA_PIN_CFG(0x0, 0x14, 0x90170110),
-	AZALIA_PIN_CFG(0x0, 0x15, 0x03211020),
-	AZALIA_PIN_CFG(0x0, 0x18, 0x03A11830),
-	AZALIA_PIN_CFG(0x0, 0x19, 0x411111F0),
-
-	0x01970804,
-	0x01870803,
-	0x01470740,
-	0x00970600,
-
-	0x00370600,
-	0x00270600,
-	0x00270600,
-	0x00270600,
-
-	AZALIA_PIN_CFG(0x0, 0x1A, 0x411111F0),
-	AZALIA_PIN_CFG(0x0, 0x1D, 0x40138205),
-	AZALIA_PIN_CFG(0x0, 0x1E, 0x411111F0),
+	AZALIA_SUBVENDOR(0x0, 0x17AA21CF),
+
+	AZALIA_PIN_CFG(0x0, 0x19, 0x04211040),
+	AZALIA_PIN_CFG(0x0, 0x1A, 0x61A19050),
+	AZALIA_PIN_CFG(0x0, 0x1B, 0x04A11060),
+	AZALIA_PIN_CFG(0x0, 0x1C, 0x6121401F),
+	AZALIA_PIN_CFG(0x0, 0x1D, 0x40F001F0),
+	AZALIA_PIN_CFG(0x0, 0x1E, 0x40F001F0),
+	AZALIA_PIN_CFG(0x0, 0x1F, 0x90170110),
+	AZALIA_PIN_CFG(0x0, 0x20, 0x40F001F0),
+	AZALIA_PIN_CFG(0x0, 0x22, 0x40F001F0),
+	AZALIA_PIN_CFG(0x0, 0x23, 0x90A60170),
 
 	/*
 	 * Hardware EQ Parameters
@@ -217,30 +179,6 @@ static const u32 mainboard_cim_verb_data[] = {
 		               Enable Combo Jack Detection */
 		0x0017A208, /* Enable ClkEn of PortSenseTst */
 		0x00170500, /* Set power state to D0 */
-
-	/* --- Next Codec --- */
-
-/*	Vendor Name    : Intel
- *	Vendor ID      : 0x80862806
- *	Subsystem ID   : 0x80860101
- *	Revision ID    : 0x100000
- */
-	/* coreboot specific header */
-	0x80862806,	// Codec Vendor / Device ID: Intel PantherPoint HDMI
-	0x80860101,	// Subsystem ID
-	0x00000004,	// Number of IDs
-
-	/* NID 0x01, HDA Codec Subsystem ID Verb Table: 0x80860101 */
-	AZALIA_SUBVENDOR(0x3, 0x80860101),
-
-	/* Pin Complex (NID 0x05) Digital Out at Int HDMI */
-	AZALIA_PIN_CFG(0x3, 0x05, 0x18560010),
-
-	/* Pin Complex (NID 0x06) Digital Out at Int HDMI */
-	AZALIA_PIN_CFG(0x3, 0x06, 0x18560020),
-
-	/* Pin Complex (NID 0x07) Digital Out at Int HDMI */
-	AZALIA_PIN_CFG(0x3, 0x07, 0x18560030)
 };
 
 static const u32 mainboard_pc_beep_verbs[] = {
@@ -18,18 +18,18 @@
  */
 
-/*	Vendor Name    : IDT
- *	Vendor ID      : 0x10ec0269
- *	Subsystem ID   : 0x17aa21fa
- *	Revision ID    : 0x100303
+/*	Vendor Name    : Conexant
+ *	Vendor ID      : 0x14f1506e
+ *	Subsystem ID   : 0x17aa21cf
+ *	Revision ID    : 0x100000
  */
 



More information about the coreboot-gerrit mailing list